
# Micro - Servicio

Micro-servicio auto generado.

# Instalación
```bash
apt install python-venv

python3 -m venv _venv

_venv/bin/pip install requirements.txt

cat .env > .env.dev
```

# Desarrollo

```bash
_venv/bin/python web.py --dev
```
